@@ -1,5 +1,5 @@
 //
-// Copyright 2014 Ettus Research LLC
+// Copyright 2014,2016 Ettus Research LLC
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -110,7 +110,8 @@ device_addrs_t octoclock_find(const device_addr_t &hint){
     //Send a query packet
     octoclock_packet_t pkt_out;
     pkt_out.proto_ver = OCTOCLOCK_FW_COMPAT_NUM;
-    pkt_out.sequence = uhd::htonx<boost::uint32_t>(std::rand());
+    // To avoid replicating sequence numbers between sessions
+    pkt_out.sequence = boost::uint32_t(std::rand());
     pkt_out.len = 0;
     pkt_out.code = OCTOCLOCK_QUERY_CMD;
     try{
@@ -137,19 +138,24 @@ device_addrs_t octoclock_find(const device_addr_t &hint){
                                               new_addr["addr"],
                                               BOOST_STRINGIZE(OCTOCLOCK_UDP_CTRL_PORT)
                                           );
-            UHD_OCTOCLOCK_SEND_AND_RECV(ctrl_xport, OCTOCLOCK_QUERY_CMD, pkt_out, len, octoclock_data);
+            UHD_OCTOCLOCK_SEND_AND_RECV(ctrl_xport, OCTOCLOCK_FW_COMPAT_NUM, OCTOCLOCK_QUERY_CMD, pkt_out, len, octoclock_data);
             if(UHD_OCTOCLOCK_PACKET_MATCHES(OCTOCLOCK_QUERY_ACK, pkt_out, pkt_in, len)){
                 //If the OctoClock is in its bootloader, don't ask for details
                 if(pkt_in->proto_ver == OCTOCLOCK_BOOTLOADER_PROTO_VER){
                     new_addr["type"] = "octoclock-bootloader";
                     octoclock_addrs.push_back(new_addr);
                 }
-                else{
+                else {
                     new_addr["type"] = "octoclock";
 
-                    octoclock_eeprom_t oc_eeprom(ctrl_xport);
-                    new_addr["name"] = oc_eeprom["name"];
-                    new_addr["serial"] = oc_eeprom["serial"];
+                    if(pkt_in->proto_ver >= OCTOCLOCK_FW_MIN_COMPAT_NUM and pkt_in->proto_ver <= OCTOCLOCK_FW_COMPAT_NUM) {
+                        octoclock_eeprom_t oc_eeprom(ctrl_xport, pkt_in->proto_ver);
+                        new_addr["name"] = oc_eeprom["name"];
+                        new_addr["serial"] = oc_eeprom["serial"];
+                    } else {
+                        new_addr["name"] = "";
+                        new_addr["serial"] = "";
+                    }
 
                     //Filter based on optional keys (if any)
                     if(
@@ -184,7 +190,8 @@ octoclock_impl::octoclock_impl(const device_addr_t &_device_addr){
     UHD_MSG(status) << "Opening an OctoClock device..." << std::endl;
     _type = device::CLOCK;
     device_addrs_t device_args = separate_device_addr(_device_addr);
-    _sequence = std::rand();
+    // To avoid replicating sequence numbers between sessions
+    _sequence = boost::uint32_t(std::rand());
 
     ////////////////////////////////////////////////////////////////////
     // Initialize the property tree
@@ -219,21 +226,21 @@ octoclock_impl::octoclock_impl(const device_addr_t &_device_addr){
         ////////////////////////////////////////////////////////////////////
         // Check the firmware compatibility number
         ////////////////////////////////////////////////////////////////////
-        boost::uint32_t fw_version = _get_fw_version(oc);
-        if(fw_version != OCTOCLOCK_FW_COMPAT_NUM){
+        _proto_ver = _get_fw_version(oc);
+        if(_proto_ver < OCTOCLOCK_FW_MIN_COMPAT_NUM or _proto_ver > OCTOCLOCK_FW_COMPAT_NUM){
             throw uhd::runtime_error(str(boost::format(
                     "\n\nPlease update your OctoClock's firmware.\n"
                     "Expected firmware compatibility number %d, but got %d:\n"
                     "The firmware build is not compatible with the host code build.\n\n"
                     "%s\n"
-                ) % int(OCTOCLOCK_FW_COMPAT_NUM) % int(fw_version) % _get_images_help_message(addr)));
+                ) % int(OCTOCLOCK_FW_COMPAT_NUM) % int(_proto_ver) % _get_images_help_message(addr)));
         }
-        _tree->create<std::string>(oc_path / "fw_version").set(boost::lexical_cast<std::string>(int(fw_version)));
+        _tree->create<std::string>(oc_path / "fw_version").set(boost::lexical_cast<std::string>(int(_proto_ver)));
 
         ////////////////////////////////////////////////////////////////////
         // Set up EEPROM
         ////////////////////////////////////////////////////////////////////
-        _oc_dict[oc].eeprom = octoclock_eeprom_t(_oc_dict[oc].ctrl_xport);
+        _oc_dict[oc].eeprom = octoclock_eeprom_t(_oc_dict[oc].ctrl_xport, _proto_ver);
         _tree->create<octoclock_eeprom_t>(oc_path / "eeprom")
             .set(_oc_dict[oc].eeprom)
             .subscribe(boost::bind(&octoclock_impl::_set_eeprom, this, oc, _1));
@@ -265,7 +272,7 @@ octoclock_impl::octoclock_impl(const device_addr_t &_device_addr){
         _get_state(oc);
         if(_oc_dict[oc].state.gps_detected){
             try{
-                _oc_dict[oc].gps = gps_ctrl::make(octoclock_make_uart_iface(_oc_dict[oc].gpsdo_xport));
+                _oc_dict[oc].gps = gps_ctrl::make(octoclock_make_uart_iface(_oc_dict[oc].gpsdo_xport, _proto_ver));
 
                 if(_oc_dict[oc].gps and _oc_dict[oc].gps->gps_detected()){
                     BOOST_FOREACH(const std::string &name, _oc_dict[oc].gps->get_sensors()){
@@ -325,30 +332,30 @@ void octoclock_impl::_set_eeprom(const std::string &oc, const octoclock_eeprom_t
 
 boost::uint32_t octoclock_impl::_get_fw_version(const std::string &oc){
     octoclock_packet_t pkt_out;
-    pkt_out.sequence = _sequence++;
+    pkt_out.sequence = uhd::htonx<boost::uint32_t>(++_sequence);
     pkt_out.len = 0;
     size_t len;
 
     boost::uint8_t octoclock_data[udp_simple::mtu];
     const octoclock_packet_t *pkt_in = reinterpret_cast<octoclock_packet_t*>(octoclock_data);
 
-    UHD_OCTOCLOCK_SEND_AND_RECV(_oc_dict[oc].ctrl_xport, OCTOCLOCK_QUERY_CMD, pkt_out, len, octoclock_data);
+    UHD_OCTOCLOCK_SEND_AND_RECV(_oc_dict[oc].ctrl_xport, OCTOCLOCK_FW_COMPAT_NUM, OCTOCLOCK_QUERY_CMD, pkt_out, len, octoclock_data);
     if(UHD_OCTOCLOCK_PACKET_MATCHES(OCTOCLOCK_QUERY_ACK, pkt_out, pkt_in, len)){
         return pkt_in->proto_ver;
     }
-    else throw uhd::runtime_error("Failed to retrive firmware version from OctoClock.");
+    else throw uhd::runtime_error("Failed to retrieve firmware version from OctoClock.");
 }
 
 void octoclock_impl::_get_state(const std::string &oc){
     octoclock_packet_t pkt_out;
-    pkt_out.sequence = _sequence++;
+    pkt_out.sequence = uhd::htonx<boost::uint32_t>(++_sequence);
     pkt_out.len = 0;
     size_t len = 0;
 
     boost::uint8_t octoclock_data[udp_simple::mtu];
     const octoclock_packet_t *pkt_in = reinterpret_cast<octoclock_packet_t*>(octoclock_data);
 
-    UHD_OCTOCLOCK_SEND_AND_RECV(_oc_dict[oc].ctrl_xport, SEND_STATE_CMD, pkt_out, len, octoclock_data);
+    UHD_OCTOCLOCK_SEND_AND_RECV(_oc_dict[oc].ctrl_xport, _proto_ver, SEND_STATE_CMD, pkt_out, len, octoclock_data);
     if(UHD_OCTOCLOCK_PACKET_MATCHES(SEND_STATE_ACK, pkt_out, pkt_in, len)){
         const octoclock_state_t *state = reinterpret_cast<const octoclock_state_t*>(pkt_in->data);
         _oc_dict[oc].state = *state;
